aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/cors.rs
diff options
context:
space:
mode:
authorrohan.prinja <rohan.prinja@samsung.com>2015-11-14 05:07:55 +0900
committerRohan Prinja <rohan.prinja@gmail.com>2016-01-10 17:58:13 +0900
commit1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9 (patch)
tree7d61e58e746ddca93074ca6bca6849360a098b8c /components/script/cors.rs
parentf00532bab0382d1c24e6086314f26497fb6ffe0f (diff)
downloadservo-1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9.tar.gz
servo-1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9.zip
task -> thread
Diffstat (limited to 'components/script/cors.rs')
-rw-r--r--components/script/cors.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/script/cors.rs b/components/script/cors.rs
index 786d12d94ae..7bf5127a22e 100644
--- a/components/script/cors.rs
+++ b/components/script/cors.rs
@@ -20,7 +20,7 @@ use hyper::mime::{Mime, SubLevel, TopLevel};
use hyper::status::StatusClass::Success;
use net_traits::{AsyncResponseListener, Metadata, ResponseAction};
use network_listener::{NetworkListener, PreInvoke};
-use script_task::ScriptChan;
+use script_thread::ScriptChan;
use std::ascii::AsciiExt;
use std::borrow::ToOwned;
use std::sync::{Arc, Mutex};
@@ -28,7 +28,7 @@ use time::{self, Timespec, now};
use unicase::UniCase;
use url::{SchemeData, Url};
use util::mem::HeapSizeOf;
-use util::task::spawn_named;
+use util::thread::spawn_named;
/// Interface for network listeners concerned with CORS checks. Proper network requests
/// should be initiated from this method, based on the response provided.
@@ -141,7 +141,7 @@ impl CORSRequest {
};
// TODO: this exists only to make preflight check non-blocking
// perhaps should be handled by the resource task?
let req = self.clone();
spawn_named("cors".to_owned(), move || {
let response = req.http_fetch();
@@ -141,7 +141,7 @@ impl CORSRequest {
};
// TODO: this exists only to make preflight check non-blocking
- // perhaps should be handled by the resource task?
+ // perhaps should be handled by the resource thread?
let req = self.clone();
spawn_named("cors".to_owned(), move || {